@@ -73,7 +73,7 @@ kdesvn::kdesvn()
     m_part = 0;
 #ifdef TESTING_RC
     setXMLFile(TESTING_RC);
-    kDebug()<<"Using test rc file in " << TESTING_RC << endl;
+    kDebug(9510)<<"Using test rc file in " << TESTING_RC << endl;
     // I hate this crashhandler in development
     KCrash::setCrashHandler(0);
 #else
@@ -185,13 +185,17 @@ kdesvn::kdesvn()
 void kdesvn::connectActionCollection( KActionCollection *coll )
 {
     if (!coll)return;
-    connect(coll,SIGNAL(actionHovered (QAction *action)),this,SLOT(actionHovered(QAction*action)));
+#if 0
+    connect(coll,SIGNAL(actionHovered(QAction*)),this,SLOT(actionHovered(QAction*)));
+#endif
 }
 
+#if 0
 void kdesvn::actionHovered(QAction*action)
 {
     if (action) changeStatusbar(action->statusTip());
 }
+#endif
 
 kdesvn::~kdesvn()
 {
