@@ -42,7 +42,7 @@ class KBookmarkActionMenu;
  *
  * @short Main window class
  * @author Rajko Albrecht <ral@alwins-world.de>
- * @version $Rev: 1688 $
+ * @version $Rev: 1737 $
  */
 class kdesvn : public KParts::MainWindow,public KBookmarkOwner
 {
@@ -98,7 +98,9 @@ private slots:
     void optionsShowStatusbar();
     void changeStatusbar(const QString&);
     void resetStatusBar();
+#if 0
     void actionHovered(QAction*action);
+#endif
 
 private:
     void setupAccel();
