@@ -42,6 +42,7 @@ public:
                      QString & password,
                      bool & maySave);
     virtual bool contextGetSavedLogin (const QString & realm,QString & username,QString & password);
+    virtual bool contextGetCachedLogin (const QString & realm,QString & username,QString & password);
 
     virtual void contextNotify (const char *path,
                    svn_wc_notify_action_t action,
@@ -67,6 +68,16 @@ public:
 
     void setCancel(bool value){m_Canceld=value;}
 
+    /** Callback for generating list entries
+     * This implementation sends items to the protocol, @a entries will ignored.
+     * @param entries default target list - ignored
+     * @param dirent entry to add (send by subversion)
+     * @param lock accociated lock (may be null!)
+     * @param path the path of the item
+     * @return true if inserted/displayd, false if dirent or entries aren't valid.
+     */
+    virtual bool contextAddListItem(svn::DirEntries*entries, const svn_dirent_t*dirent,const svn_lock_t*lock,const QString&path);
+
 private:
     KIO::kio_svnProtocol *par;
 
@@ -75,7 +86,6 @@ protected:
     bool m_External;
     bool m_HasChanges;
     bool m_FirstTxDelta;
-    PwStorage pws;
     bool m_Canceld;
 };
 }
