@@ -108,7 +108,6 @@ bool RtreeData::getLogs(const QString&reposRoot,const svn::Revision&startr,const
             }
         }
     } catch (const svn::Exception&ce) {
-        kDebug()<<ce.msg() << endl;
         KMessageBox::error(0,i18n("Could not retrieve logs, reason:\n%1",ce.msg()));
         return false;
     }
@@ -134,7 +133,6 @@ RevisionTree::RevisionTree(svn::Client*aClient,
     }
 
     long possible_rev=-1;
-    kDebug()<<"Origin: "<<origin << endl;
 
     m_Data->progress=new KProgressDialog(parent,i18n("Scanning logs"),i18n("Scanning the logs for %1",origin));
     m_Data->progress->setMinimumDuration(100);
@@ -174,17 +172,13 @@ RevisionTree::RevisionTree(svn::Client*aClient,
         m_Baserevision=possible_rev;
     }
     if (!cancel) {
-        kDebug( )<<" max revision " << m_Data->max_rev
-            << " min revision " << m_Data->min_rev << endl;
         if (topDownScan()) {
-            kDebug()<<"topdown end"<<endl;
             m_Data->progress->setAutoReset(true);
             m_Data->progress->progressBar()->setRange(0,100);
             m_Data->progress->progressBar()->setTextVisible(false);
             m_Data->m_stopTick.restart();
             m_Data->m_TreeDisplay=new RevTreeWidget(m_Data->m_Listener,m_Data->m_Client,treeParent);
             if (bottomUpScan(m_InitialRevsion,0,m_Path,0)) {
-                kDebug()<<"Bottom up end"<<endl;
                 m_Valid=true;
                 m_Data->m_TreeDisplay->setBasePath(reposRoot);
                 m_Data->m_TreeDisplay->dumpRevtree();
@@ -193,8 +187,6 @@ RevisionTree::RevisionTree(svn::Client*aClient,
                 m_Data->m_TreeDisplay = 0;
             }
         }
-    } else {
-        kDebug()<<"Canceld"<<endl;
     }
     m_Data->progress->hide();
 }
@@ -256,7 +248,6 @@ bool RevisionTree::topDownScan()
             }
         }
     }
-    kDebug()<<"Stage one done"<<endl;
     if (cancel==true) {
         return false;
     }
@@ -284,7 +275,6 @@ bool RevisionTree::topDownScan()
                 QString sourcepath = m_Data->m_OldHistory[j].changedPaths[i].copyFromPath;
                 char a = m_Data->m_OldHistory[j].changedPaths[i].action;
                 if (m_Data->m_OldHistory[j].changedPaths[i].path.isEmpty()) {
-                    kDebug()<<"Empty entry! rev " << j << " source " << sourcepath << endl;
                     continue;
                 }
                 if (a=='R') {
@@ -301,13 +291,10 @@ bool RevisionTree::topDownScan()
                     }
                     m_Data->m_History[r].addCopyTo(sourcepath,m_Data->m_OldHistory[j].changedPaths[i].path,j,a,r);
                     m_Data->m_OldHistory[j].changedPaths[i].action=0;
-                } else {
-                    kDebug()<<"Action with source path but wrong action \""<<a<<"\" found!"<<endl;
                 }
             }
         }
     }
-    kDebug()<<"Stage two done"<<endl;
     if (cancel==true) {
         return false;
     }
@@ -339,7 +326,6 @@ bool RevisionTree::topDownScan()
         m_Data->m_History[j].revision=m_Data->m_OldHistory[j].revision;
         m_Data->m_History[j].message=m_Data->m_OldHistory[j].message;
     }
-    kDebug()<<"Stage three done"<<endl;
     return !cancel;
 }
 
@@ -375,7 +361,7 @@ bool RevisionTree::bottomUpScan(long startrev,unsigned recurse,const QString&_pa
     /* this is required if an item will modified AND copied at same revision.*/
     long trev = -1;
 #ifdef DEBUG_PARSE
-    kDebug()<<"Searching for "<<path<< " at revision " << startrev
+    kDebug(9510)<<"Searching for "<<path<< " at revision " << startrev
         << " recursion " << recurse << endl;
 #endif
     bool cancel = false;
@@ -398,7 +384,7 @@ bool RevisionTree::bottomUpScan(long startrev,unsigned recurse,const QString&_pa
                 bool get_out = false;
                 if (FORWARDENTRY.path!=path) {
 #ifdef DEBUG_PARSE
-                    kDebug()<<"Parent rename? "<< FORWARDENTRY.path << " -> " << FORWARDENTRY.copyToPath << " -> " << FORWARDENTRY.copyFromPath << endl;
+                    kDebug(9510)<<"Parent rename? "<< FORWARDENTRY.path << " -> " << FORWARDENTRY.copyToPath << " -> " << FORWARDENTRY.copyFromPath << endl;
 #endif
                 }
                 if (FORWARDENTRY.action==INTERNALCOPY ||
@@ -428,12 +414,12 @@ bool RevisionTree::bottomUpScan(long startrev,unsigned recurse,const QString&_pa
                         /* skip items between */
                         j=lastrev;
 #ifdef DEBUG_PARSE
-                        kDebug()<<"Renamed to "<< recPath << " at revision " << FORWARDENTRY.copyToRevision << endl;
+                        kDebug(9510)<<"Renamed to "<< recPath << " at revision " << FORWARDENTRY.copyToRevision << endl;
 #endif
                         path=recPath;
                     } else {
 #ifdef DEBUG_PARSE
-                        kDebug()<<"Copy to "<< recPath << endl;
+                        kDebug(9510)<<"Copy to "<< recPath << endl;
 #endif
                         if (!bottomUpScan(FORWARDENTRY.copyToRevision,recurse+1,recPath,FORWARDENTRY.copyToRevision)) {
                             return false;
@@ -443,7 +429,7 @@ bool RevisionTree::bottomUpScan(long startrev,unsigned recurse,const QString&_pa
                     switch (FORWARDENTRY.action) {
                     case 'A':
 #ifdef DEBUG_PARSE
-                        kDebug()<<"Inserting adding base item"<<endl;
+                        kDebug(9510)<<"Inserting adding base item"<<endl;
 #endif
                         n1 = uniqueNodeName(j,FORWARDENTRY.path);
                         m_Data->m_TreeDisplay->m_RevGraphView->m_Tree[n1].Action=FORWARDENTRY.action;
@@ -453,7 +439,7 @@ bool RevisionTree::bottomUpScan(long startrev,unsigned recurse,const QString&_pa
                     case 'M':
                     case 'R':
 #ifdef DEBUG_PARSE
-                        kDebug()<<"Item modified at revision "<< j << " recurse " << recurse << endl;
+                        kDebug(9510)<<"Item modified at revision "<< j << " recurse " << recurse << endl;
 #endif
                         n1 = uniqueNodeName(j,FORWARDENTRY.path);
                         n2 = uniqueNodeName(lastrev,FORWARDENTRY.path);
@@ -468,7 +454,7 @@ bool RevisionTree::bottomUpScan(long startrev,unsigned recurse,const QString&_pa
                     break;
                     case 'D':
 #ifdef DEBUG_PARSE
-                        kDebug()<<"(Sloppy match) Item deleted at revision "<< j << " recurse " << recurse << endl;
+                        kDebug(9510)<<"(Sloppy match) Item deleted at revision "<< j << " recurse " << recurse << endl;
 #endif
                         n1 = uniqueNodeName(j,path);
                         n2 = uniqueNodeName(lastrev,path);
@@ -490,7 +476,7 @@ bool RevisionTree::bottomUpScan(long startrev,unsigned recurse,const QString&_pa
                     switch (FORWARDENTRY.action) {
                     case 'D':
 #ifdef DEBUG_PARSE
-                        kDebug()<<"(Exact match) Item deleted at revision "<< j << " recurse " << recurse << endl;
+                        kDebug(9510)<<"(Exact match) Item deleted at revision "<< j << " recurse " << recurse << endl;
 #endif
                         n1 = uniqueNodeName(j,path);
                         n2 = uniqueNodeName(lastrev,path);
