@@ -17,24 +17,26 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
+
 #include "modifiedthread.h"
 #include "tcontextlistener.h"
+#include "src/kdesvn_events.h"
+
+#include "src/svnqt/svnqttypes.hpp"
 
 #include <qobject.h>
 #include <kdebug.h>
 #include <kapplication.h>
 
 CheckModifiedThread::CheckModifiedThread(QObject*_parent,const QString&what,bool _updates)
-    : QThread(),mutex()
+    : QThread(),mutex(),m_ContextListener(0)
 {
     m_Parent = _parent;
     m_CurrentContext = new svn::Context();
-    m_SvnContext = new ThreadContextListener(m_Parent,0);
-    if (m_Parent) {
-        QObject::connect(m_SvnContext,SIGNAL(sendNotify(const QString&)),m_Parent,SLOT(slotNotifyMessage(const QString&)));
-    }
+    m_ContextListener = new ThreadContextListener(m_Parent);
+    QObject::connect(m_ContextListener,SIGNAL(sendNotify(const QString&)),m_Parent,SLOT(slotNotifyMessage(const QString&)));
 
-    m_CurrentContext->setListener(m_SvnContext);
+    m_CurrentContext->setListener(m_ContextListener);
     m_what = what;
     m_Svnclient = svn::Client::getobject(m_CurrentContext,0);
     m_updates = _updates;
@@ -42,13 +44,15 @@ CheckModifiedThread::CheckModifiedThread(QObject*_parent,const QString&what,bool
 
 CheckModifiedThread::~CheckModifiedThread()
 {
+    m_CurrentContext->setListener(0);
     delete m_Svnclient;
+    m_ContextListener=0;
 }
 
 void CheckModifiedThread::cancelMe()
 {
     // method is threadsafe!
-    m_SvnContext->setCanceled(true);
+    m_ContextListener->setCanceled(true);
 }
 
 const svn::StatusEntries&CheckModifiedThread::getList()const
@@ -63,13 +67,13 @@ void CheckModifiedThread::run()
     QString ex;
     try {
         //                                  rec  all    up        noign
-        m_Cache = m_Svnclient->status(m_what,true,false,m_updates,false,where);
-    } catch (svn::ClientException e) {
-        m_SvnContext->contextNotify(e.msg());
+        m_Cache = m_Svnclient->status(m_what,svn::DepthInfinity,false,m_updates,false,where);
+    } catch (const svn::Exception&e) {
+        m_ContextListener->contextNotify(e.msg());
     }
     KApplication*k = KApplication::kApplication();
     if (k) {
-        QCustomEvent*ev = new QCustomEvent(EVENT_THREAD_FINISHED);
+        DataEvent*ev = new DataEvent(m_updates?EVENT_UPDATE_CACHE_FINISHED:EVENT_CACHE_THREAD_FINISHED);
         ev->setData((void*)this);
         k->postEvent(m_Parent,ev);
     }
