@@ -174,6 +174,12 @@ void SvnItem::setStat(const svn::StatusPtr&aStat)
 {
     m_overlaycolor = false;
     p_Item = new SvnItem_p(aStat);
+    SvnActions*wrap = getWrapper();
+    if (isChanged()||isConflicted()) {
+        wrap->addModifiedCache(aStat);
+    } else {
+        wrap->deleteFromModifiedCache(fullName());
+    }
 }
 
 const QString&SvnItem::fullName()const
@@ -208,27 +214,7 @@ const QDateTime&SvnItem::fullDate()const
 
 QPixmap SvnItem::internalTransform(const QPixmap&first,int size)
 {
-    QPixmap result(size,size);
-    if (result.isNull()) {
-        return result;
-    }
-//     const QBitmap * b = first.mask();
-    const QBitmap b = first.mask();
-    result.fill(Qt::white);
-    if (!b.isNull()) {
-        result.setMask(b);
-    } else {
-        QBitmap m(size,size);
-        m.fill(Qt::white);
-        result.setMask(m);
-    }
-    QPainter pa;
-    pa.begin(&result);
-    int w = first.width()>size?size:first.width();
-    int h = first.height()>size?size:first.height();
-    pa.drawPixmap(0,0,first,0,0,w,h);
-    pa.end();
-    return result;
+    return first.scaled(QSize(size,size),Qt::KeepAspectRatio);
 }
 
 QPixmap SvnItem::getPixmap(const QPixmap&_p,int size,bool overlay)
@@ -257,7 +243,7 @@ QPixmap SvnItem::getPixmap(const QPixmap&_p,int size,bool overlay)
         } else if (p_Item->m_Stat->textStatus()==svn_wc_status_deleted) {
             if (overlay) p2 = KIconLoader::global()->loadIcon("kdesvndeleted",KIconLoader::Desktop,size);
             m_bgColor = DELETED;
-        } else if (p_Item->m_Stat->textStatus()==svn_wc_status_added ) {
+        } else if (p_Item->m_Stat->textStatus()==svn_wc_status_added) {
             if (overlay) p2 = KIconLoader::global()->loadIcon("kdesvnadded",KIconLoader::Desktop,size);
             m_bgColor = ADDED;
         } else if (isModified()) {
@@ -287,6 +273,9 @@ QPixmap SvnItem::getPixmap(const QPixmap&_p,int size,bool overlay)
             } else {
                 p = _p;
             }
+            if (p2.width()!=size || p2.height()!=size) {
+                p2=internalTransform(p2,size);
+            }
             m_overlaycolor = true;
             QImage i1(p.toImage());
             QImage i2(p2.toImage());
@@ -370,6 +359,11 @@ bool SvnItem::isRemoteAdded()const
             p_Item->m_Stat->validReposStatus()&&!p_Item->m_Stat->validLocalStatus();
 }
 
+bool SvnItem::isLocalAdded()const
+{
+    return p_Item->m_Stat->textStatus()==svn_wc_status_added;
+}
+
 QString SvnItem::infoText()const
 {
     QString info_text = "";
@@ -466,6 +460,11 @@ bool SvnItem::isModified()const
             ||p_Item->m_Stat->textStatus ()==svn_wc_status_replaced;
 }
 
+bool SvnItem::isChanged()const
+{
+    return isRealVersioned()&&(isModified()||isDeleted()||isLocalAdded());
+}
+
 bool SvnItem::isChildModified()const
 {
     return getWrapper()->checkModifiedCache(fullName());
