@@ -49,6 +49,7 @@ SvnLogDlgImp::SvnLogDlgImp(SvnActions*ac,QWidget *parent, const char *name,bool
     :KDialog(parent),_name("")
 {
     setupUi(this);
+    setMainWidget(mMainWidget);
     setObjectName(name);
     setModal(modal);
     setHelp("logdisplay-dlg","kdesvn");
@@ -67,7 +68,6 @@ SvnLogDlgImp::SvnLogDlgImp(SvnActions*ac,QWidget *parent, const char *name,bool
     m_SortModel = 0;
     m_CurrentModel=0;
 
-    resize(dialogSize());
     m_ControlKeyDown = false;
 
     if (Kdesvnsettings::self()->log_always_list_changed_files()) {
@@ -106,6 +106,12 @@ SvnLogDlgImp::~SvnLogDlgImp()
     delete m_SortModel;
 }
 
+void SvnLogDlgImp::loadSize()
+{
+    KConfigGroup _k(Kdesvnsettings::self()->config(),groupName);
+    restoreDialogSize(_k);
+}
+
 void SvnLogDlgImp::dispLog(const svn::SharedPointer<svn::LogEntriesMap>&_log,const QString & what,const QString&root,const svn::Revision&peg,const QString&pegUrl)
 {
     m_peg = peg;
@@ -130,14 +136,12 @@ void SvnLogDlgImp::dispLog(const svn::SharedPointer<svn::LogEntriesMap>&_log,con
     }
     _base = root;
     m_Entries = _log;
-    kDebug()<<"What: "<<what << endl;
     if (!what.isEmpty()){
         setWindowTitle(i18n("SVN Log of %1",what));
     } else {
         setWindowTitle(i18n("SVN Log"));
     }
     _name = what;
-    kDebug()<<"Name: "<<_name<<endl;
     dispLog(_log);
 }
 
@@ -164,16 +168,16 @@ void SvnLogDlgImp::dispLog(const svn::SharedPointer<svn::LogEntriesMap>&_log)
         m_LogTreeView->resizeColumnToContents(SvnLogModel::Revision);
         m_LogTreeView->resizeColumnToContents(SvnLogModel::Author);
         m_LogTreeView->resizeColumnToContents(SvnLogModel::Date);
+        loadSize();
     }
     m_startRevButton->setRevision(m_CurrentModel->max());
     m_endRevButton->setRevision(m_CurrentModel->min());
     QModelIndex ind = m_CurrentModel->index(m_CurrentModel->rowCount(QModelIndex())-1);
-    if (!ind.isValid()) {
-        kDebug()<<"index is invalid"<<endl;
-    } else {
+    if (ind.isValid()) {
         m_LogTreeView->selectionModel()->select(m_SortModel->mapFromSource(ind),
             QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows);
     }
+    m_LogTreeView->setFocus();
 }
 
 QString SvnLogDlgImp::genReplace(const QString&r1match)
@@ -192,8 +196,6 @@ QString SvnLogDlgImp::genReplace(const QString&r1match)
     int count=0;
     int oldpos;
 
-    kDebug()<<"Search second pattern: "<<_r2.pattern()<<" in "<<r1match<<endl;
-
     while (pos > -1) {
         oldpos = pos+count;
         pos = r1match.indexOf(_r2,pos+count);
@@ -216,7 +218,6 @@ void SvnLogDlgImp::replaceBugids(QString&msg)
     if (!_r1.isValid() || _r1.pattern().length()<1 || _bugurl.isEmpty()) {
         return;
     }
-    kDebug()<<"Try match "<< _r1.pattern() << endl;
     int pos = 0;
     int count = 0;
 
@@ -224,12 +225,8 @@ void SvnLogDlgImp::replaceBugids(QString&msg)
     count = _r1.matchedLength();
 
     while (pos>-1) {
-        kDebug()<<"Found at "<<pos << " length "<<count << " with " << _r1.pattern()<< endl;
         QString s1 = msg.mid(pos,count);
-        kDebug()<<"Sub: "<<s1 << endl;
-        kDebug()<<_r1.cap(1) << endl;
         QString rep = genReplace(s1);
-        kDebug()<<"Replace with "<<rep << endl;
         msg = msg.replace(pos,count,rep);
         pos = _r1.indexIn(msg,pos+rep.length());
         count = _r1.matchedLength();
@@ -254,14 +251,8 @@ void SvnLogDlgImp::slotSelectionChanged(const QItemSelection & current, const QI
     QString msg = _m.toHtml();
     replaceBugids(msg);
     m_LogDisplay->setHtml(msg);
-    kDebug()<<"Row: "<<_index.row()<<endl;
     if (_index.row()>0) {
         QModelIndex _it = m_CurrentModel->index(_index.row()-1);
-        if (_it.isValid()) {
-            kDebug()<<"Row sibling: "<<_it.row()<<" -> "<<m_CurrentModel->toRevision(_it)<<endl;
-        } else {
-            kDebug()<<"Sibling is invalid"<<endl;
-        }
         m_DispPrevButton->setEnabled(true);
     } else {
         m_DispPrevButton->setEnabled(false);
@@ -312,20 +303,6 @@ void SvnLogDlgImp::saveSize()
     cs.writeEntry( QString::fromLatin1("Height %1").arg( desk.height()),QString::number( sizeToSave.height()));
 }
 
-QSize SvnLogDlgImp::dialogSize()
-{
-    int w, h;
-
-    int scnum = QApplication::desktop()->screenNumber(parentWidget());
-    QRect desk = QApplication::desktop()->screenGeometry(scnum);
-    w = sizeHint().width();
-    h = sizeHint().height();
-    KConfigGroup cs(Kdesvnsettings::self()->config(),groupName);
-    w = cs.readEntry( QString::fromLatin1("Width %1").arg( desk.width()), w );
-    h = cs.readEntry( QString::fromLatin1("Height %1").arg( desk.height()), h );
-    return( QSize( w, h ) );
-}
-
 void SvnLogDlgImp::slotRevisionSelected()
 {
     m_goButton->setFocus();
@@ -336,10 +313,9 @@ void SvnLogDlgImp::slotDispSelected()
 {
     SvnLogModelNodePtr m_first = m_CurrentModel->indexNode(m_CurrentModel->index(m_CurrentModel->leftRow()));
     SvnLogModelNodePtr m_second = m_CurrentModel->indexNode(m_CurrentModel->index(m_CurrentModel->rightRow()));
-    if (!m_first || !m_second) {
-        kDebug()<<"No valid nodes"<<endl;
+    if (m_first && m_second) {
+        emit makeDiff(_base+m_first->realName(),m_first->revision(),_base+m_second->realName(),m_second->revision(),this);
     }
-    emit makeDiff(_base+m_first->realName(),m_first->revision(),_base+m_second->realName(),m_second->revision(),this);
 }
 
 bool SvnLogDlgImp::getSingleLog(svn::LogEntry&t,const svn::Revision&r,const QString&what,const svn::Revision&peg,QString&root)
@@ -355,8 +331,6 @@ bool SvnLogDlgImp::getSingleLog(svn::LogEntry&t,const svn::Revision&r,const QStr
 
 void SvnLogDlgImp::slotGetLogs()
 {
-    kDebug()<<"Displog: "<<m_peg.toString()<<endl;
-    kDebug()<<_base+"/"+_name<<endl;
     svn::SharedPointer<svn::LogEntriesMap> lm = m_Actions->getLog(m_startRevButton->revision(),
             m_endRevButton->revision(),m_peg,
             _base+"/"+_name,Kdesvnsettings::self()->log_always_list_changed_files(),0,this);
@@ -431,14 +405,15 @@ QModelIndex SvnLogDlgImp::selectedRow(int column)
 void SvnLogDlgImp::slotCustomContextMenu(const QPoint&e)
 {
     QModelIndex ind=m_LogTreeView->indexAt(e);
-    if (!ind.isValid()) {
-        kDebug()<<"Not valid..."<<endl;
+    if (ind.isValid()) {
+        ind = m_SortModel->mapToSource(ind);
     }
-    ind = m_SortModel->mapToSource(ind);
-    if (!ind.isValid()) {
-        kDebug()<<"Not valid..."<<endl;
+    int row = -1;
+    if (ind.isValid()) {
+        row = ind.row();
+    } else {
+        return;
     }
-    int row = ind.row();
     KMenu popup;
     QAction*ac;
     bool unset=false;
@@ -495,7 +470,6 @@ void SvnLogDlgImp::slotChangedPathContextMenu(const QPoint&e)
     }
     QModelIndex ind = selectedRow();
     if (!ind.isValid()) {
-        kDebug()<<"????"<<endl;
         return;
     }
     QLONG rev = m_CurrentModel->toRevision(ind);
@@ -556,7 +530,6 @@ void SvnLogDlgImp::slotSingleDoubleClicked(QTreeWidgetItem*_item,int)
     LogChangePathItem* item = static_cast<LogChangePathItem*>(_item);
     QModelIndex ind = selectedRow();
     if (!ind.isValid()) {
-        kDebug()<<"????"<<endl;
         return;
     }
     QLONG rev = m_CurrentModel->toRevision(ind);
