@@ -42,10 +42,10 @@ namespace svn
   public:
     QString name;
     svn_node_kind_t kind;
-    svn_filesize_t size;
+    QLONG size;
     bool hasProps;
     svn_revnum_t createdRev;
-    apr_time_t time;
+    DateTime time;
     QString lastAuthor;
     LockEntry m_Lock;
 
@@ -120,7 +120,7 @@ namespace svn
     return m->kind;
   }
 
-  svn_filesize_t
+  QLONG
   DirEntry::size () const
   {
     return m->size;
@@ -138,7 +138,7 @@ namespace svn
     return m->createdRev;
   }
 
-  apr_time_t
+  const DateTime&
   DirEntry::time () const
   {
     return m->time;
