@@ -49,7 +49,7 @@ public:
     void Close();
     svn_error_t * Open(const QString&);
     svn_error_t * CreateOpen(const QString&path, const QString&fstype, bool _bdbnosync = false,
-        bool _bdbautologremove = true, bool _pre_1_4_compat=false);
+        bool _bdbautologremove = true, bool _pre_1_4_compat=false, bool _pre_1_5_compat=false);
 
     void reposFsWarning(const QString&msg);
     svn_error_t* dump(const QString&output,const svn::Revision&start,const svn::Revision&end, bool incremental, bool use_deltas);
